News
====

* **26.03.2026** Version 2026.1 released (axisymmetric linear elasticity
  example, Saint Venant-Kirchhoff hyperelastic term, improved generalized Yeoh
  term, rigid twist linear combination boundary conditions + example, sparse
  arrays are used instead of sparse matrices, new mesh creation and
  manipulation utilities, etc.), see :ref:`release notes <2025.4-2026.1>`.

* **29.12.2025** Version 2025.4 released (Python 2 code clean up, improved
  vector field visualizations in sfepy-view, etc.), see :ref:`release notes
  <2025.3-2025.4>`.

* **29.09.2025** Version 2025.3 released (efficient region-only connectivity
  updates, fixed Field.set_dofs() for nonzero arrays, etc.), see :ref:`release
  notes <2025.2-2025.3>`.

* **26.06.2025** Version 2025.2 released (NumPy 2.0 compatibility, line search
  variants of the Newton solver for nonlinear problems, new large deformation
  exponential fibres term with smooth response, etc.), see :ref:`release notes
  <2025.1-2025.2>`.

* **26.03.2025** Version 2025.1 released (improved block preconditioning
  support in PETSc-based linear solvers, user functions for assembling and
  linear system scaling, pypardiso based linear solver, general hyperelastic
  term for the UL formulation, speed-up of sparse matrix graph allocation and
  assembling of matrices with many nonzeros in a row, etc.), see :ref:`release
  notes <2024.4-2025.1>`.

For historians: see :ref:`archived_news`.
